==> opencart-4.1.0.0.zip: upload/admin/language/fr-fr/sale/order.php <==
<?php
// En-tête
$_['heading_title']              = 'Commandes';

// Texte
$_['text_success']               = 'Succès: Vous avez modifié les commandes!';
$_['text_list']                  = 'Liste des commandes';
$_['text_add']                   = 'Ajouter une commande';
$_['text_edit']                  = 'Commande (#%s)';
$_['text_filter']                = 'Filtrer';
$_['text_store']                 = 'Boutique';
$_['text_date_added']            = 'Date d\'ajout';
$_['text_customer']              = 'Client';
$_['text_cart_add']              = 'Ajouter un article';
$_['text_product_add']           = 'Ajouter un produit';
$_['text_voucher_add']           = 'Ajouter un bon';
$_['text_points']                = 'Points';
$_['text_reward']                = 'Points de fidélité';
$_['text_reward_add']            = 'Succès: Points de fidélité ajoutés!';
$_['text_reward_remove']         = 'Succès: Points de fidélité supprimés!';
$_['text_affiliate']             = 'Affilié';
$_['text_commission']            = 'Commission';
$_['text_commission_add']        = 'Succès: Commission ajoutée!';
$_['text_commission_remove']     = 'Succès: Commission supprimée!';
$_['text_restock']               = 'Succès: Les produits ont été réapprovisionnés!';
$_['text_upload']                = 'Votre fichier a été téléchargé avec succès!';
$_['text_subscription']          = 'Abonnement';
$_['text_subscription_trial']    = '%s tous les %d %s(s) pour %d paiement(s), puis ';
$_['text_subscription_duration'] = '%s tous les %d %s(s) pour %d paiement(s)';
$_['text_subscription_cancel']   = '%s tous les %d %s(s) jusqu\'à annulation';
$_['text_day']                   = 'jour';
$_['text_week']                  = 'semaine';
$_['text_semi_month']            = 'demi-mois';
$_['text_month']                 = 'mois';
$_['text_year']                  = 'année';
$_['text_more']                  = 'Plus..';
$_['text_less']                  = 'Moins..';
$_['text_payment_address']       = 'Adresse de facturation';
$_['text_payment_method']        = 'Mode de paiement';
$_['text_payment']               = 'Veuillez sélectionner le mode de paiement préféré pour cette commande.';
$_['text_shipping_address']      = 'Adresse de livraison';
$_['text_shipping_method']       = 'Mode de livraison';
$_['text_shipping']              = 'Veuillez sélectionner le mode de livraison préféré pour cette commande.';
$_['text_comment']               = 'Commentaire';
$_['text_history']               = 'Historique';
$_['text_history_add']           = 'Ajouter à l\'historique';
$_['text_browser']               = 'Navigateur';
$_['text_ip']                    = 'Adresse IP';
$_['text_forwarded_ip']          = 'IP transférée';
$_['text_user_agent']            = 'Agent utilisateur';
$_['text_accept_language']       = 'Langue acceptée';
$_['text_order_id']              = 'ID de commande';
$_['text_website']               = 'Site Web';
$_['text_invoice']               = 'Facture';
$_['text_invoice_no']            = 'N° de facture';
$_['text_store_address']         = 'Adresse de la boutique';
$_['text_store_telephone']       = 'Téléphone de la boutique';
$_['text_store_email']           = 'E-Mail de la boutique';
$_['text_customer_email']        = 'E-Mail du client';
$_['text_customer_telephone']    = 'Téléphone du client';
$_['text_missing']               = 'Commandes manquantes';
$_['text_default']               = 'Par défaut';
$_['text_picklist']              = 'Note d\'expédition';

// Colonne
$_['column_order_id']            = 'ID de commande';
$_['column_customer']            = 'Client';
$_['column_store']               = 'Boutique';
$_['column_status']              = 'Statut';
$_['column_date_added']          = 'Date d\'ajout';
$_['column_date_modified']       = 'Date de modification';
$_['column_total']               = 'Total';
$_['column_product']             = 'Produit';
$_['column_model']               = 'Modèle';
$_['column_quantity']            = 'Quantité';
$_['column_price']               = 'Prix unitaire';
$_['column_comment']             = 'Commentaire';
$_['column_notify']              = 'Client notifié';
$_['column_location']            = 'Emplacement';
$_['column_reference']           = 'Référence';
$_['column_weight']              = 'Poids du produit';
$_['column_action']              = 'Action';

// Entrée
$_['entry_store']                = 'Boutique';
$_['entry_customer']             = 'Client';
$_['entry_customer_group']       = 'Groupe de clients';
$_['entry_firstname']            = 'Prénom';
$_['entry_lastname']             = 'Nom de famille';
$_['entry_email']                = 'E-Mail';
$_['entry_telephone']            = 'Téléphone';
$_['entry_address']              = 'Choisir une adresse';
$_['entry_company']              = 'Entreprise';
$_['entry_address_1']            = 'Adresse 1';
$_['entry_address_2']            = 'Adresse 2';
$_['entry_city']                 = 'Ville';
$_['entry_postcode']             = 'Code postal';
$_['entry_country']              = 'Pays';
$_['entry_zone']                 = 'Région / État';
$_['entry_product']              = 'Choisir un produit';
$_['entry_option']               = 'Choisir une/des option(s)';
$_['entry_subscription']         = 'Choisir un abonnement';
$_['entry_quantity']             = 'Quantité';
$_['entry_to_name']              = 'Nom du destinataire';
$_['entry_to_email']             = 'E-mail du destinataire';
$_['entry_from_name']            = 'Nom de l\'expéditeur';
$_['entry_from_email']           = 'E-mail de l\'expéditeur';
$_['entry_theme']                = 'Thème du bon cadeau';
$_['entry_message']              = 'Message';
$_['entry_amount']               = 'Montant';
$_['entry_order_status']         = 'Statut de la commande';
$_['entry_notify']               = 'Notifier le client';
$_['entry_override']             = 'Outrepasser';
$_['entry_comment']              = 'Commentaire';
$_['entry_language']             = 'Langue';
$_['entry_currency']             = 'Devise';
$_['entry_affiliate']            = 'Affilié';
$_['entry_coupon']               = 'Coupon';
$_['entry_voucher']              = 'Bon';
$_['entry_reward']               = 'Utiliser des points de fidélité';
$_['entry_shipping_method']      = 'Mode de livraison';
$_['entry_payment_method']       = 'Mode de paiement';
$_['entry_order_id']             = 'ID de commande';
$_['entry_total']                = 'Total';
$_['entry_date_from']            = 'Date de début';
$_['entry_date_to']              = 'Date de fin';

// Aide
$_['help_override']              = 'Si la commande du client est bloquée pour changer le statut de la commande en raison d\'une extension anti-fraude, activez le dépassement.';

// Erreur
$_['error_warning']              = 'Avertissement: Veuillez vérifier attentivement le formulaire pour les erreurs!';
$_['error_permission']           = 'Avertissement: Vous n\'avez pas la permission de modifier les commandes!';
$_['error_invoice_no']           = 'Avertissement: Le N° de facture a déjà été créé!';
$_['error_order']                = 'Avertissement: La commande n\'existe pas!';
$_['error_affiliate']            = 'Avertissement: L\'affilié n\'existe pas!';
$_['error_reward_add']           = 'Avertissement: Les points de fidélité pour cette commande ont déjà été ajoutés!';
$_['error_commission_add']       = 'Avertissement: La commission affiliée pour cette commande a déjà été ajoutée!';

==> opencart-4.1.0.3.zip: upload/admin/language/fr-fr/sale/order.php <==
<?php
// En-tête
$_['heading_title']              = 'Commandes';

// Texte
$_['text_success']               = 'Succès: Vous avez modifié les commandes!';
$_['text_list']                  = 'Liste des commandes';
$_['text_add']                   = 'Ajouter une commande';
$_['text_edit']                  = 'Commande (#%s)';
$_['text_filter']                = 'Filtrer';
$_['text_store']                 = 'Boutique';
$_['text_date_added']            = 'Date d\'ajout';
$_['text_customer']              = 'Client';
$_['text_product_add']           = 'Ajouter un produit';
$_['text_model'] 			     = 'Modèle';
$_['text_reward']                = 'Points de récompenses';
$_['text_points']                = 'Points';
$_['text_reward_add']            = 'Succès: Points de récompenses ajoutés!';
$_['text_reward_remove']         = 'Succès: Points de récompenses supprimés!';
$_['text_affiliate']             = 'Affilié';
$_['text_commission']            = 'Commission';
$_['text_commission_add']        = 'Succès: Commission ajoutée!';
$_['text_commission_remove']     = 'Succès: Commission supprimée!';
$_['text_upload']                = 'Votre fichier a été téléchargé avec succès!';
$_['text_subscription']          = 'Abonnement';
$_['text_subscription_trial']    = '%s tous les %d %s(s) pour %d paiement(s), puis ';
$_['text_subscription_duration'] = '%s tous les %d %s(s) pour %d paiement(s)';
$_['text_subscription_cancel']   = '%s tous les %d %s(s) jusqu\'à annulation';
$_['text_day']                   = 'jour';
$_['text_week']                  = 'semaine';
$_['text_semi_month']            = 'demi-mois';
$_['text_month']                 = 'mois';
$_['text_year']                  = 'année';
$_['text_more']                  = 'Plus..';
$_['text_less']                  = 'Moins..';
$_['text_payment_address']       = 'Adresse de facturation';
$_['text_payment_method']        = 'Mode de paiement';
$_['text_payment']               = 'Veuillez sélectionner le mode de paiement préféré pour cette commande.';
$_['text_shipping_address']      = 'Adresse d\'expédition';
$_['text_shipping_method']       = 'Mode d\'expédition';
$_['text_shipping']              = 'Veuillez sélectionner le mode d\'Expédition préféré pour cette commande.';
$_['text_comment']               = 'Commentaire';
$_['text_history']               = 'Historique';
$_['text_history_add']           = 'Ajouter à l\'historique';
$_['text_browser']               = 'Navigateur';
$_['text_ip']                    = 'Adresse IP';
$_['text_forwarded_ip']          = 'IP transférée';
$_['text_user_agent']            = 'Agent utilisateur';
$_['text_accept_language']       = 'Langue acceptée';
$_['text_order_id']              = 'ID de commande';
$_['text_website']               = 'Site Web';
$_['text_invoice']               = 'Facture';
$_['text_invoice_no']            = 'N° de facture';
$_['text_tbc']                   = 'À confirmer';
$_['text_store_address']         = 'Adresse de la boutique';
$_['text_store_telephone']       = 'Téléphone de la boutique';
$_['text_store_email']           = 'E-Mail de la boutique';
$_['text_customer_email']        = 'E-Mail du client';
$_['text_customer_telephone']    = 'Téléphone du client';
$_['text_missing']               = 'Commandes manquantes';
$_['text_default']               = 'Par défaut';
$_['text_picklist']              = 'Note d\'expédition';
$_['text_sku']                   = 'SKU';
$_['text_upc']                   = 'UPC';
$_['text_ean']                   = 'EAN';
$_['text_jan']                   = 'JAN';
$_['text_isbn']                  = 'ISBN';
$_['text_mpn']                   = 'MPN';

// Colonne
$_['column_order_id']            = 'ID de commande';
$_['column_customer']            = 'Client';
$_['column_store']               = 'Boutique';
$_['column_status']              = 'Statut';
$_['column_date_added']          = 'Date d\'ajout';
$_['column_date_modified']       = 'Date de modification';
$_['column_total']               = 'Total';
$_['column_product']             = 'Produit';
$_['column_model']               = 'Modèle';
$_['column_quantity']            = 'Quantité';
$_['column_price']               = 'Prix unitaire';
$_['column_comment']             = 'Commentaire';
$_['column_notify']              = 'Client notifié';
$_['column_location']            = 'Emplacement';
$_['column_reference']           = 'Référence';
$_['column_weight']              = 'Poids du produit';
$_['column_action']              = 'Action';

// Entrée
$_['entry_store']                = 'Boutique';
$_['entry_customer']             = 'Client';
$_['entry_customer_group']       = 'Groupe de clients';
$_['entry_firstname']            = 'Prénom';
$_['entry_lastname']             = 'Nom de famille';
$_['entry_email']                = 'E-Mail';
$_['entry_telephone']            = 'Téléphone';
$_['entry_address']              = 'Choisir une adresse';
$_['entry_company']              = 'Entreprise';
$_['entry_address_1']            = 'Adresse 1';
$_['entry_address_2']            = 'Adresse 2';
$_['entry_city']                 = 'Ville';
$_['entry_postcode']             = 'Code postal';
$_['entry_country']              = 'Pays';
$_['entry_zone']                 = 'Région / État';
$_['entry_product']              = 'Choisir un produit';
$_['entry_option']               = 'Choisir une/des option(s)';
$_['entry_subscription']         = 'Choisir un abonnement';
$_['entry_quantity']             = 'Quantité';
$_['entry_order_status']         = 'Statut de la commande';
$_['entry_notify']               = 'Notifier le client';
$_['entry_shipping_method']      = 'Mode d\'expédition';
$_['entry_payment_method']       = 'Mode de paiement';
$_['entry_override']             = 'Outrepasser';
$_['entry_comment']              = 'Commentaire';
$_['entry_language']             = 'Langue';
$_['entry_currency']             = 'Devise';
$_['entry_affiliate']            = 'Affilié';
$_['entry_order_id']             = 'ID de commande';
$_['entry_total']                = 'Total';
$_['entry_date_from']            = 'Date de début';
$_['entry_date_to']              = 'Date de fin';
$_['entry_date_modified_from']   = 'Date de modification à partir de';
$_['entry_date_modified_to']     = 'Date de modification jusqu\'à';

// Aide
$_['help_override']              = 'Si la commande du client est bloquée pour changer le statut de la commande en raison d\'une extension anti-fraude, activez le dépassement.';

// Erreur
$_['error_warning']              = 'Avertissement: Veuillez vérifier attentivement le formulaire pour les erreurs!';
$_['error_permission']           = 'Avertissement: Vous n\'avez pas la permission de modifier les commandes!';
$_['error_invoice_no']           = 'Avertissement: Le N° de facture a déjà été créé!';
$_['error_order']                = 'Avertissement: La commande n\'existe pas!';
$_['error_affiliate']            = 'Avertissement: L\'affilié n\'existe pas!';
$_['error_reward_add']           = 'Avertissement: Les points de récompenses pour cette commande ont déjà été ajoutés!';
$_['error_reward_guest']         = 'Avertissement: Les invités ne peuvent pas utiliser les points de récompenses!';
$_['error_commission_add']       = 'Avertissement: La commission affiliée pour cette commande a déjà été ajoutée!';
